<?php
/**
 * Active callbacks for Theme/Customzer Options
 *
 * @package Catch Themes
 * @subpackage Catch Responsive
 * @since Catch Responsive 3.4
 */

if ( ! defined( 'CATCHRESPONSIVE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

if( ! function_exists( 'catchresponsive_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_demo_slider_inactive( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && !( 'demo-featured-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_post_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-post-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_page_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-page-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_category_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-category-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_image_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-image-slider' == $type ) );
	}
endif;

if( ! function_exists( 'catchresponsive_is_featured_content_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_content_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_demo_featured_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_demo_featured_content_inactive( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is not demo content
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && !( 'demo-featured-content' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_post_content_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-post-content' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_page_content_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-page-content' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_category_content_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-category-content' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_image_content_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_option]' )->value();

		$type 	= $control->manager->get_setting( 'catchresponsive_theme_options[featured_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'homepage' ) ) && ( 'featured-image-content' == $type ) );
	}
endif;


if( ! function_exists( 'catchresponsive_is_featured_content_background_image_enabled' ) ) :
	/**
	* Return true if featured content background image is not disabled
	*
	* @since  Catch Responsive 3.4
	*/
	function catchresponsive_is_featured_content_background_image_enabled( $control ) {
		return !$control->manager->get_setting( 'catchresponsive_theme_options[featured_content_disable_background_image]' )->value();
	}
endif;

if( ! function_exists( 'catchresponsive_is_header_top_enabled' ) ) :
	/**
	* Return true if is top header is not enabled
	*
	* @since  Catch Responsive 1.1
	*/
	function catchresponsive_is_header_top_enabled( $control ) {
		return !$control->manager->get_setting( 'catchresponsive_theme_options[disable_header_top]' )->value();
	}
endif;

